@@ -58,7 +58,7 @@ from .iotcontrol.time_graph import TimeGraph, TimeGraphLine, DataPoint
 from .iotcontrol.knob import Knob
 from .iotcontrol.dial import Dial
 from .iotcontrol.direction import Direction
-from .iotcontrol.map import Map, MapLocation, SimpleMapLocation
+from .iotcontrol.map import Map, MapLocation
 from .iotcontrol.alarm import Alarm
 from .iotcontrol.menu import Menu
 from .iotcontrol.selector import Selector
