@@ -1,9 +1,25 @@
-"""Button
+"""
+MIT License
 
-Returns
--------
-Button
-    A Button control
+Copyright (c) 2020 DashIO-Connect
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 """
 from ..constants import BAD_CHARS
 from .control import Control
@@ -168,8 +184,9 @@ class Button(Control):
 
     @text.setter
     def text(self, val: str):
-        self._cfg["text"] = val
-        self.state_str = self._control_hdr_str + f"{self._btn_state.value}\t{self._icon_name.value}\t{val}\n"
+        _val = val.translate(BAD_CHARS)
+        self._cfg["text"] = _val
+        self.state_str = self._control_hdr_str + f"{self._btn_state.value}\t{self._icon_name.value}\t{_val}\n"
 
     @property
     def btn_state(self) -> ButtonState:
