@@ -78,7 +78,7 @@ class Control:
         """This is called by iotdashboard app. Controls need to implement their own version."""
         return ""
 
-    def get_cfg(self, num_columns):
+    def get_cfg(self, data):
         """Returns the CFG for the control called when the iotdashboard app asks for a CFG
 
         Parameters
@@ -91,9 +91,15 @@ class Control:
         str
             The CFG for this control
         """
+        logging.debug("CFG: %s", data)
+        try:
+            num_columns = data[3]
+            dashboard_id = data[2]
+        except IndexError:
+            return
         if self.control_position:
             self.control_position.set_size(num_columns)
-        cfg_str = "\tCFG\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
+        cfg_str = f"\tCFG\t{dashboard_id}\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
     def __init__(self, cntrl_type: str, control_id: str, title=None, control_position=None, title_position=None):
@@ -126,7 +132,6 @@ class Control:
         self.message_rx_event = Event()
         self.message_tx_event = Event()
         self._control_hdr_str = f"\t{{device_id}}\t{self.cntrl_type}\t{self.control_id}\t"
-        self._tx_message = ""
         self._control_position = None
         if control_position is not None:
             self.control_position = control_position
@@ -144,7 +149,6 @@ class Control:
 
     @state_str.setter
     def state_str(self, val):
-        self._tx_message = val
         self.message_tx_event(val)
 
     # Use getter, setter properties to store the settings in the config dictionary
