@@ -1,5 +1,25 @@
 """
-    All the different Enum definitions in one conveniant place.
+MIT License
+
+Copyright (c) 2020 DashIO-Connect
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 """
 from enum import Enum
 
@@ -86,10 +106,16 @@ class SoundName(Enum):
     PLOP = "Plop"
     PLOPPLIPPLIP = "Plop Plip Plip"
     SWITCH = "Switch"
-    WHOOSH = "Woosh"
+    WHOOSH = "Whoosh"
     BOING = "Boing"
 
 
+class ColorPickerStyle(Enum):
+    """Picker styles"""
+    WHEEL = "Wheel"
+    SPECTRUM = "SPectrum"
+
+
 class LabelStyle(Enum):
     """Label styles"""
     BASIC = "BASIC"
