@@ -1,4 +1,26 @@
-"""textbox.py"""
+"""
+MIT License
+
+Copyright (c) 2020 DashIO-Connect
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
 from ..constants import BAD_CHARS
 from .control import Control
 from .enums import (Keyboard, Precision, TextAlignment, TextFormat,
@@ -74,8 +96,9 @@ class TextBox(Control):
 
     @text.setter
     def text(self, val: str):
-        self._text = val
-        self.state_str = self._control_hdr_str + f"{self.text}\n"
+        _val = val.translate(BAD_CHARS)
+        self._text = _val
+        self.state_str = self._control_hdr_str + f"{_val}\n"
 
     @property
     def text_align(self) -> TextAlignment:
@@ -122,7 +145,8 @@ class TextBox(Control):
 
     @units.setter
     def units(self, val: str):
-        self._cfg["units"] = val
+        _val = val.translate(BAD_CHARS)
+        self._cfg["units"] = _val
 
     @property
     def precision(self) -> Precision:
