@@ -49,7 +49,7 @@ class TCP():
         """
         return ""
 
-    def get_cfg(self, _) -> str:
+    def get_cfg(self, data) -> str:
         """Returns the CFG string for this TCP control
 
         Returns
@@ -57,7 +57,12 @@ class TCP():
         str
             The CFG string for this control
         """
-        cfg_str = "\tCFG\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
+        try:
+            num_columns = data[3]
+            dashboard_id = data[2]
+        except IndexError:
+            return
+        cfg_str = f"\tCFG\t{dashboard_id}\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
     def __init__(self, control_id, ip_address="", port=5650):
